abacusai.stt_gen_model_options — AbacusAI documentation

# abacusai.stt_gen_model_options

## Classes

`SttGenModelOptions` | STT generation model options

## Module Contents

class abacusai.stt_gen_model_options.SttGenModelOptions(client, keys=None, values=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  STT generation model options

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - keys (list) – The keys of the image generation model options represented as the enum values.

    - values (list) – The display names of the image generation model options.

  keys = None
  values = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict